"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_agreement_products_api import CommissionAgreementProductsApi  # noqa: E501


class TestCommissionAgreementProductsApi(unittest.TestCase):
    """CommissionAgreementProductsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionAgreementProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_agreement_product(self):
        """Test case for create_commission_agreement_product

        Create the commission agreement product  # noqa: E501
        """
        pass

    def test_delete_commission_agreement_product(self):
        """Test case for delete_commission_agreement_product

        Delete the commission agreement product  # noqa: E501
        """
        pass

    def test_get_commission_agreement_product(self):
        """Test case for get_commission_agreement_product

        Retrieve the commission agreement product  # noqa: E501
        """
        pass

    def test_list_commission_agreement_products(self):
        """Test case for list_commission_agreement_products

        List commission agreement products  # noqa: E501
        """
        pass

    def test_update_commission_agreement_product(self):
        """Test case for update_commission_agreement_product

        Update the commission agreement product  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_agreements_api import CommissionAgreementsApi  # noqa: E501


class TestCommissionAgreementsApi(unittest.TestCase):
    """CommissionAgreementsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionAgreementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_agreement(self):
        """Test case for create_commission_agreement

        Create the commission agreement  # noqa: E501
        """
        pass

    def test_delete_commission_agreement(self):
        """Test case for delete_commission_agreement

        Delete the commission agreement  # noqa: E501
        """
        pass

    def test_get_commission_agreement(self):
        """Test case for get_commission_agreement

        Retrieve the commission agreement  # noqa: E501
        """
        pass

    def test_list_commission_agreements(self):
        """Test case for list_commission_agreements

        List commission agreements  # noqa: E501
        """
        pass

    def test_patch_commission_agreement_status(self):
        """Test case for patch_commission_agreement_status

        Update the commission agreement status  # noqa: E501
        """
        pass

    def test_update_commission_agreement(self):
        """Test case for update_commission_agreement

        Update the commission agreement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commissions_api import CommissionsApi  # noqa: E501


class TestCommissionsApi(unittest.TestCase):
    """CommissionsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission(self):
        """Test case for create_commission

        Create the commission  # noqa: E501
        """
        pass

    def test_delete_commission(self):
        """Test case for delete_commission

        Delete the commission  # noqa: E501
        """
        pass

    def test_estimate_commission(self):
        """Test case for estimate_commission

        Retrieve the estimate commissions  # noqa: E501
        """
        pass

    def test_get_commission(self):
        """Test case for get_commission

        Retrieve the commission  # noqa: E501
        """
        pass

    def test_list_commissions(self):
        """Test case for list_commissions

        List commissions  # noqa: E501
        """
        pass

    def test_update_commission(self):
        """Test case for update_commission

        Update the commission  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_settlements_api import CommissionSettlementsApi  # noqa: E501


class TestCommissionSettlementsApi(unittest.TestCase):
    """CommissionSettlementsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionSettlementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_settlement(self):
        """Test case for create_commission_settlement

        Create the commission settlement  # noqa: E501
        """
        pass

    def test_delete_commission_settlement(self):
        """Test case for delete_commission_settlement

        Delete the commission settlement  # noqa: E501
        """
        pass

    def test_get_commission_settlement(self):
        """Test case for get_commission_settlement

        Retrieve the commission settlement  # noqa: E501
        """
        pass

    def test_list_commission_settlements(self):
        """Test case for list_commission_settlements

        List commission settlements  # noqa: E501
        """
        pass

    def test_publish_commission_settlements(self):
        """Test case for publish_commission_settlements

        Create the commission settlement publish  # noqa: E501
        """
        pass

    def test_update_commission_settlement(self):
        """Test case for update_commission_settlement

        Update the commission settlement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_agreement_versions_api import CommissionAgreementVersionsApi  # noqa: E501


class TestCommissionAgreementVersionsApi(unittest.TestCase):
    """CommissionAgreementVersionsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionAgreementVersionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_agreement_version(self):
        """Test case for create_commission_agreement_version

        Create the commission agreement version  # noqa: E501
        """
        pass

    def test_delete_commission_agreement_version(self):
        """Test case for delete_commission_agreement_version

        Delete the commission agreement version  # noqa: E501
        """
        pass

    def test_get_commission_agreement_version(self):
        """Test case for get_commission_agreement_version

        Retrieve the commission agreement version  # noqa: E501
        """
        pass

    def test_list_commission_agreement_versions(self):
        """Test case for list_commission_agreement_versions

        List commission agreement versions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()




# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from eis.commission.api.commission_agreement_products_api import CommissionAgreementProductsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from eis.commission.api.commission_agreement_products_api import CommissionAgreementProductsApi
from eis.commission.api.commission_agreement_rules_api import CommissionAgreementRulesApi
from eis.commission.api.commission_agreement_versions_api import CommissionAgreementVersionsApi
from eis.commission.api.commission_agreements_api import CommissionAgreementsApi
from eis.commission.api.commission_candidates_api import CommissionCandidatesApi
from eis.commission.api.commission_recipients_api import CommissionRecipientsApi
from eis.commission.api.commission_settlements_api import CommissionSettlementsApi
from eis.commission.api.commissions_api import CommissionsApi
from eis.commission.api.default_api import DefaultApi



"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.commission
from eis.commission.model.create_commission_item_request_dto import CreateCommissionItemRequestDto
globals()['CreateCommissionItemRequestDto'] = CreateCommissionItemRequestDto
from eis.commission.model.create_commission_request_dto import CreateCommissionRequestDto


class TestCreateCommissionRequestDto(unittest.TestCase):
    """CreateCommissionRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCommissionRequestDto(self):
        """Test CreateCommissionRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCommissionRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.commission
from eis.commission.model.update_commission_settlement_request_dto import UpdateCommissionSettlementRequestDto


class TestUpdateCommissionSettlementRequestDto(unittest.TestCase):
    """UpdateCommissionSettlementRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateCommissionSettlementRequestDto(self):
        """Test UpdateCommissionSettlementRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateCommissionSettlementRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from eis.commission.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from eis.commission.model.commission_agreement_class import CommissionAgreementClass
from eis.commission.model.commission_agreement_metadata_dto import CommissionAgreementMetadataDto
from eis.commission.model.commission_agreement_metadata_partner_dto import CommissionAgreementMetadataPartnerDto
from eis.commission.model.commission_agreement_product_class import CommissionAgreementProductClass
from eis.commission.model.commission_agreement_rule_class import CommissionAgreementRuleClass
from eis.commission.model.commission_agreement_rule_config_dto import CommissionAgreementRuleConfigDto
from eis.commission.model.commission_agreement_rule_evaluation_class import CommissionAgreementRuleEvaluationClass
from eis.commission.model.commission_agreement_version_class import CommissionAgreementVersionClass
from eis.commission.model.commission_candidate_class import CommissionCandidateClass
from eis.commission.model.commission_class import CommissionClass
from eis.commission.model.commission_conditions_dto import CommissionConditionsDto
from eis.commission.model.commission_config_dto import CommissionConfigDto
from eis.commission.model.commission_estimate_class import CommissionEstimateClass
from eis.commission.model.commission_item_class import CommissionItemClass
from eis.commission.model.commission_recipient_class import CommissionRecipientClass
from eis.commission.model.commission_settlement_class import CommissionSettlementClass
from eis.commission.model.create_commission_agreement_product_request_dto import CreateCommissionAgreementProductRequestDto
from eis.commission.model.create_commission_agreement_product_response_class import CreateCommissionAgreementProductResponseClass
from eis.commission.model.create_commission_agreement_request_dto import CreateCommissionAgreementRequestDto
from eis.commission.model.create_commission_agreement_response_class import CreateCommissionAgreementResponseClass
from eis.commission.model.create_commission_agreement_rule_request_dto import CreateCommissionAgreementRuleRequestDto
from eis.commission.model.create_commission_agreement_rule_response_class import CreateCommissionAgreementRuleResponseClass
from eis.commission.model.create_commission_agreement_version_request_dto import CreateCommissionAgreementVersionRequestDto
from eis.commission.model.create_commission_agreement_version_response_class import CreateCommissionAgreementVersionResponseClass
from eis.commission.model.create_commission_candidate_request_dto import CreateCommissionCandidateRequestDto
from eis.commission.model.create_commission_candidate_response_class import CreateCommissionCandidateResponseClass
from eis.commission.model.create_commission_item_request_dto import CreateCommissionItemRequestDto
from eis.commission.model.create_commission_recipient_request_dto import CreateCommissionRecipientRequestDto
from eis.commission.model.create_commission_recipient_response_class import CreateCommissionRecipientResponseClass
from eis.commission.model.create_commission_request_dto import CreateCommissionRequestDto
from eis.commission.model.create_commission_response_class import CreateCommissionResponseClass
from eis.commission.model.create_commission_settlement_request_dto import CreateCommissionSettlementRequestDto
from eis.commission.model.create_commission_settlement_response_class import CreateCommissionSettlementResponseClass
from eis.commission.model.estimate_commissions_request_dto import EstimateCommissionsRequestDto
from eis.commission.model.estimate_commissions_response_class import EstimateCommissionsResponseClass
from eis.commission.model.evaluate_commission_agreement_rule_request_dto import EvaluateCommissionAgreementRuleRequestDto
from eis.commission.model.evaluate_commission_agreement_rule_response_class import EvaluateCommissionAgreementRuleResponseClass
from eis.commission.model.evaluated_commission_class import EvaluatedCommissionClass
from eis.commission.model.get_commission_agreement_product_response_class import GetCommissionAgreementProductResponseClass
from eis.commission.model.get_commission_agreement_response_class import GetCommissionAgreementResponseClass
from eis.commission.model.get_commission_agreement_rule_response_class import GetCommissionAgreementRuleResponseClass
from eis.commission.model.get_commission_agreement_version_response_class import GetCommissionAgreementVersionResponseClass
from eis.commission.model.get_commission_candidate_response_class import GetCommissionCandidateResponseClass
from eis.commission.model.get_commission_recipient_response_class import GetCommissionRecipientResponseClass
from eis.commission.model.get_commission_response_class import GetCommissionResponseClass
from eis.commission.model.get_commission_settlement_response_class import GetCommissionSettlementResponseClass
from eis.commission.model.inline_response200 import InlineResponse200
from eis.commission.model.inline_response503 import InlineResponse503
from eis.commission.model.list_commission_agreement_products_response_class import ListCommissionAgreementProductsResponseClass
from eis.commission.model.list_commission_agreement_rules_response_class import ListCommissionAgreementRulesResponseClass
from eis.commission.model.list_commission_agreement_versions_response_class import ListCommissionAgreementVersionsResponseClass
from eis.commission.model.list_commission_agreements_response_class import ListCommissionAgreementsResponseClass
from eis.commission.model.list_commission_candidates_response_class import ListCommissionCandidatesResponseClass
from eis.commission.model.list_commission_recipients_response_class import ListCommissionRecipientsResponseClass
from eis.commission.model.list_commission_settlements_response_class import ListCommissionSettlementsResponseClass
from eis.commission.model.list_commissions_response_class import ListCommissionsResponseClass
from eis.commission.model.patch_commission_agreement_status_request_dto import PatchCommissionAgreementStatusRequestDto
from eis.commission.model.patch_commission_agreement_status_response_class import PatchCommissionAgreementStatusResponseClass
from eis.commission.model.publish_commission_settlements_request_dto import PublishCommissionSettlementsRequestDto
from eis.commission.model.publish_commission_settlements_response_class import PublishCommissionSettlementsResponseClass
from eis.commission.model.update_commission_agreement_product_request_dto import UpdateCommissionAgreementProductRequestDto
from eis.commission.model.update_commission_agreement_product_response_class import UpdateCommissionAgreementProductResponseClass
from eis.commission.model.update_commission_agreement_request_dto import UpdateCommissionAgreementRequestDto
from eis.commission.model.update_commission_agreement_response_class import UpdateCommissionAgreementResponseClass
from eis.commission.model.update_commission_agreement_rule_request_dto import UpdateCommissionAgreementRuleRequestDto
from eis.commission.model.update_commission_agreement_rule_response_class import UpdateCommissionAgreementRuleResponseClass
from eis.commission.model.update_commission_candidate_request_dto import UpdateCommissionCandidateRequestDto
from eis.commission.model.update_commission_candidate_response_class import UpdateCommissionCandidateResponseClass
from eis.commission.model.update_commission_recipient_request_dto import UpdateCommissionRecipientRequestDto
from eis.commission.model.update_commission_recipient_response_class import UpdateCommissionRecipientResponseClass
from eis.commission.model.update_commission_request_dto import UpdateCommissionRequestDto
from eis.commission.model.update_commission_response_class import UpdateCommissionResponseClass
from eis.commission.model.update_commission_settlement_request_dto import UpdateCommissionSettlementRequestDto
from eis.commission.model.update_commission_settlement_response_class import UpdateCommissionSettlementResponseClass
